locale = {
        [":("] = ":(",
        ["!!!"] = "!!!",
        ["..."] = "...",
        ["Accuracy Bonus!"] = "Bonus za presnosť!",
        ["a Hedgewars mini-game"] = "minihra Hedgewars", -- Space_Invasion, The_Specialists
	["Aiming Practice"] = "Tréning presnosti", --Bazooka, Shotgun, SniperRifle
        ["Ammo"] = "Výzbroj",
        ["Ammo Depleted!"] = "Výzbroj vyčerpaná!",
--      ["Ammo Maniac!"] = "",
        ["Available points remaining: "] = "Zostávajúci počet bodov: ",
	["Bat balls at your enemies and|push them into the sea!"] = "Loptami triafajte vašich nepriateľov|a zhoďte ich tak do mora!",
	["Bat your opponents through the|baskets and out of the map!"] = "Odpálkujte vašich súperov do koša|a von z mapy!",
	["Bazooka Training"] = "Tréning s bazukou",
	["Best laps per team: "] = "Najrýchlejšie kolá podľa tímov: ",
        ["Best Team Times: "] = "Najrýchlejšie tímové časy: ",
        ["Bloody Rookies"] = "Mizerní zelenáči", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree
        ["BOOM!"] = "BUM!",
        ["Boom!"] = "Bum!",
        ["Boss defeated!"] = "Vodca bol porazený!",
--      ["Boss Slayer!"] = "",
        ["CAPTURE THE FLAG"] = "ZMOCNITE SA VLAJKY",
        ["Careless"] = "Bezstarostný",
        ["Clumsy"] = "Nešikovný",
        ["Codename: Teamwork"] = "Kódové meno: Tímová práca",
--      ["Complete the track as fast as you can!"] = "",
        ["Congratulations!"] = "Gratulujem!",
	["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Gratulujem! Zneškodnili ste všetky ciele|v stanovenom čase.", --Bazooka, Shotgun, SniperRifle
        ["Control pillars to score points."] = "Ovládnite piliere, aby ste skórovali",
        ["Cybernetic Empire"] = "Kybertnetické impérium",
        ["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "Do kelu s tebou, zelenáč! Okamžite mi zlez z hlavy!",
        ["DAMMIT, ROOKIE!"] = "Prekliaty zelenáč!",
        ["Dangerous Ducklings"] = "Nebezpečné kačiatka",
--      ["Deadweight"] = "",
--      ["Depleted Kamikaze!"] = "",
--      ["Destroy invaders to score points."] = "",
--      ["Drone Hunter!"] = "",
--      ["Drowner"] = "",
--      ["Each turn you get 1-3 random weapons"] = "",
        ["Each turn you get one random weapon"] = "Každé koho dostanete jednu náhodnú zbraň",
        ["Eliminate all enemies"] = "Zneškodnite všetkých nepriateľov",
	["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Zneškodnite všetky ciele pred vypršaním času.|Na túto misiu máte neobmedzené množstvo streliva.", --Bazooka, Shotgun, SniperRifle
        ["Eliminate Poison before the time runs out"] = "Zneškodnite Poisona pred tým, ako vyprší čas",
        ["Eliminate the Blue Team"] = "Zneškodnite modrý tím",
--      ["Eliminate the enemy specialists."] = "",
        ["- Eliminate Unit 3378 |- Feeble Resistance must survive"] = "- Zneškodnite Jednotku 3378|- Slabý odpor musí prežiť",
        ["Enjoy the swim..."] = "Užite si plávanie...",
--      ["[Enter]"] = "",
	["Fastest lap: "] = "Najrýchlejšie kolo: ",
        ["Feeble Resistance"] = "Slabý odpor",
--      ["Fire"] = "",
        ["Flag captured!"] = "Získaná vlajka!",
        ["Flag respawned!"] = "Vlajka obnovená!",
        ["Flag returned!"] = "Vlajka vrátená!",
--      ["Flags, and their home base will be placed where each team ends their first turn."] = "",
        ["GAME BEGUN!!!"] = "HRA ZAČALA!!!",
        ["Game Modifiers: "] = "Modifikátory hry: ",
        ["GAME OVER!"] = "KONIEC HRY!",
        ["Game Started!"] = "Hra začala!",
        ["Get on over there and take him out!"] = "Okamžite sa tam presuň a zneškodni ho!",
        ["Goal"] = "Cieľ",
        ["GO! GO! GO!"] = "POHYB! POHYB! POHYB!",
        ["Good birdy......"] = "Dobrý vtáčik......",
        ["Good luck out there!"] = "Veľa šťastia!",
        ["GOTCHA!"] = "A MÁM ŤA!",
        ["Hahahaha!"] = "Hehehehe!",
        ["Haha, now THAT would be something!"] = "Haha, tak TO by bolo niečo!",
--      ["Hapless Hogs"] = "",
--      [" Hapless Hogs left!"] = "",
        ["Heavy"] = "Ťažký",
	["Hedgewars-Basketball"] = "Hedgewars-Basketbal",
	["Hedgewars-Knockball"] = "Hedgewars-Knockball",
        ["Heh, it's not that bad."] = "Heh, to nie je také zlé.",
--      ["Hit Combo!"] = "",
        ["Hmmm..."] = "Hmm..",
        ["Hooray!"] = "Hurá!",
	["Hunter"] = "Lovec", --Bazooka, Shotgun, SniperRifle
        ["Instructor"] = "Inštruktor", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings
--      ["invaders destroyed"] = "",
--      ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "",
--      ["Jumping is disabled"] = "",
--      ["Kamikaze Expert!"] = "",
        ["KILLS"] = "ZABITÍ:",
        ["[Left Shift]"] = "[Ľavý Shift]",
        ["Listen up, maggot!!"] = "Počúvaj, ty biedny červ!",
        ["|- Mines Time:"] = "|- Časovač pre míny:", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
        ["MISSION FAILED"] = "MISIA NEÚSPEŠNÁ", -- User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["MISSION SUCCESS"] = "",
        ["MISSION SUCCESSFUL"] = "MISIA ÚSPEŠNÁ", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
        ["Movement: [Up], [Down], [Left], [Right]"] = "Pohyb: [Hore], [Dole], [Vľavo], [Vpravo]",
--      ["Multi-shot!"] = "",
        ["Nameless Heroes"] = "Hrdinovia bez mena",
        ["NEW CLAN RECORD: "] = "NOVÝ KLANOVÝ REKORD: ",
	["NEW fastest lap: "] = "NOVÉ najrýchlejšie kolo: ",
--      ["NEW RACE RECORD: "] = "",
--      ["NOT ENOUGH WAYPOINTS"] = "",
	["Not So Friendly Match"] = "Nie tak celkom priateľský zápas", -- Basketball, Knockball
        ["Oh no! Just try again!"] = "Áále nie! Tak to skúste znovu!", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
	["Oh no! Time's up! Just try again."] = "Áále nie! Čas vypršal! Tak to skúste znovu.", --Bazooka, Shotgun, SniperRifle
        ["Operation Diver"] = "Operácia Potápač",
        ["Opposing Team: "] = "Nepriateľský tím",
        ["Pathetic Hog #%d"] = "Žalostný ježko #%d",
        ["Per-Hog Ammo"] = "Samostatná munícia pre ježkov",
        ["Place more waypoints using [ENTER]"] = "Umiesnite viac bodov pomocou [ENTER]u",
        ["points"] = "body", -- Control, CTF_Blizzard, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle
        ["Poison"] = "Poison",
        ["Power Remaining"] = "Zostáva energie",
        ["Press [Precise] to skip intro"] = "Stlačte [Presnejšie mierenie] pre preskočenie intra",
--      ["Race complexity limit reached."] = "",
        [" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"] = " - Skórujete prinesením nepriateľskej vlajky do vašej základne | -  Prvý tím, ktorý dosiahne 3 body, vyhráva | - Skórujete len vtedy, keď je máte svoju vlajku v základni | - Spadnuté vlajky môžu byť vrátené na základňu alebo sa ich môže zmocniť súpere | - Ježkovia po smrti ožiujú",
        ["Round Limit"] = "Limit na kolo",
        ["Rounds Complete"] = "Dokončených kôl",
        ["RULES OF THE GAME [Press ESC to view]"] = "PRAVIDLÁ HRY [Stlačte Esc pre ich zobrazenie]",
--      ["s|"] = "",
--      ["Save as many hapless hogs as possible!"] = "",
        ["SCORE"] = "SKÓRE",
        ["sec"] = "sek", -- CTF_Blizzard, TrophyRace, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork, Capture_the_Flag
        ["See ya!"] = "Tak zatiaľ!",
        ["s"] = "s", -- GaudyRacer, Space_Invasion
        ["Shield boosted! +30 power"] = "Štít posilnený! Energia +30",
        ["Shield Depleted"] = "Štít vyčerpaný",
        ["Shield is fully recharged!"] = "Štít je plne nabitý!",
--      ["Shield Master!"] = "",
--      ["Shield Miser!"] = "",
        ["Shield OFF:"] = "Štít VYPNUTÝ:",
        ["Shield ON:"] = "Štít ZAPNUTÝ:",
        ["Shield Seeker!"] = "Hľadač štítov!",
	["Shotgun Team"] = "Shotgun tím",
	["Shotgun Training"] = "Tréning s brokovnicou",
        ["Shots Left: "] = "Zostáva striel: ", -- GaudyRacer, Tumbler
--      ["Silly"] = "",
--      ["Sinky"] = "",
	["%s is out and Team %d|scored a penalty!| |Score:"] = "%s je mimo hru a tím %d|dostal trestný bod!| |Skóre:", -- Basketball, Knockball
	["%s is out and Team %d|scored a point!| |Score:"] = "%s je mimo hru a tím %d|získal bod!| |Skóre:", -- Basketball, Knockball
	["Sniper Training"] = "Tréning pre ostreľovačov",
	["Sniperz"] = "Ostreľovači",
--      ["Sponge"] = "",
        ["Spooky Tree"] = "Strašidelný strom",
--      ["STATUS UPDATE"] = "", -- GaudyRacer, Space_Invasion
        ["Switched to "] = "Prepnuté na ",
	["Team %d: "] = "Tím %d: ",
--      ["Team Scores"] = "", -- Control, Space_Invasion
--      ["That Sinking Feeling"] = "",
        ["That was pointless."] = "To bolo zbytočné.",
        ["The enemy is hiding out on yonder ducky!"] = "Nepriateľ sa schováva na tamtej kačičke!",
        ["The flag will respawn next round."] = "V ďalšom kole sa obnoví vlajka.",
--      ["The Nameless One"] = "",
        ["THE SPECIALISTS"] = "ŠPECIALISTI",
        ["This rain is really something..."] = "Ten dážď naozaj stojí za to...",
        ["TIME: "] = "ČAS: ",
--      ["Timed Kamikaze!"] = "",
        ["Time Extended!"] = "Predĺžený čas!",
        ["Time Left: "] = "Zostávajúci čas: ",
        ["Toggle Shield"] = "Prepnúť štít",
        ["Toxic Team"] = "Toxic tím", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["TRACK COMPLETED"] = "",
        ["Track Time: "] = "Čas: ",
	["TrophyRace"] = "Preteky o trofej",
        ["T_T"] = "T_T",
        ["Turn Time"] = "Čas na ťah",
        ["Unit 3378"] = "Jednotka 3378",
        ["Unlimited Attacks"] = "Neobmedzené útoky",
--      ["User Challenge"] = "",
	["Use your rope to get from start to finish as fast as you can!"] = "Použite lano na presun zo štartovnej pozície do cieľa tak rýchlo, ako to len viete!",
        ["v.06"] = "v.06",
        ["Victory for the "] = "Víťazstvo pre", -- CTF_Blizzard, Capture_the_Flag
--      ["Waypoint placed."] = "",
--      ["Weapons Reset"] = "",
        ["WINNING TIME: "] = "ČAS PRE VÍŤAZSTVO: ",
--      ["You'd almost swear the water was rising!"] = "",
        ["You have SCORED!!"] = "SKÓROVALI ste!!",
        ["You saved"] = "Zachránili ste",
        ["You've failed. Try again."] = "Neuspeli ste. Skúste to znova.",
	["You've reached the goal!| |Time: "] = "Dosiahli ste cieľ!| |Čas: ",
	["'Zooka Team"] = "Bazuka tím",
    }
